# Ce fichier est dans le domaine public. N'hésitez pas à la modifier pour vos
# propres écrans

##############################################################################
# Dialogues
#
# Écrans utilisés pour le mode ADV
# http://www.renpy.org/doc/html/screen_special.html#say
screen say:

    # Valeurs par défaut de 'side_image' et 'two_window'
    default side_image = None
    default two_window = False

    # Options selon le que l'on soit en mode une fenêtre ou deux fenêtres.
    if not two_window:

        # Cas avec une fenêtre.
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # Cas avec deux fenêtres.
        vbox:
            style "say_two_window_vbox"

            if who:
                window:
                    style "say_who_window"

                    text who:
                        id "who"

            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"

    # Si il y a une image latérale, on la montre au dessus du texte.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Utilisation du menu rapide.
    use quick_menu


##############################################################################
# Choix
#
# Écran utilisé pour les menus au sein du jeu
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice:

    window:
        style "menu_window"
        xalign 0.5
        yalign 0.5

        vbox:
            style "menu"
            spacing 2

            for caption, action, chosen in items:

                if action:

                    button:
                        action action
                        style "menu_choice_button"

                        text caption style "menu_choice"

                else:
                    text caption style "menu_caption"

init -2 python:
    config.narrator_menu = True

    style.menu_window.set_parent(style.default)
    style.menu_choice.set_parent(style.button_text)
    style.menu_choice.clear()
    style.menu_choice_button.set_parent(style.button)
    style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
    style.menu_choice_button.xmaximum = int(config.screen_width * 0.75)


##############################################################################
# Entrée
#
# Écran utilisé lors de l'utilisation de renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input:

    window style "input_window":
        has vbox

        text prompt style "input_prompt"
        input id "input" style "input_text"

    use quick_menu

##############################################################################
# Nvl
#
# Écran utilisé pour les dialogues et les menus en mode NVL
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl:

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Affiche un dialogue
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Affiche un menu si il y en a un
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0

    use quick_menu

##############################################################################
# Menu principal
#
# Écran utilisé pour le menu principal, quand Ren'Py démarre
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu:

    # Pour être sûr que tout autre menu est remplacé
    tag menu

    # Le fond du menu principal
    window:
        style "mm_root"

    # Les boutons du menu principal.
    frame:
        style_group "mm"
        xalign 0.5
        yalign 0.95
        background None

        has hbox

        imagebutton:
            style "accueil_bouton"
            idle Text(u"\uE069",style = "accueil_idle")
            if _preferences.language == None:
                hover Text("Read in\nEnglish", style = "accueil_hover")
                action Language("en")
            else:
                hover Text("Lire en\nfrançais", style = "accueil_hover")
                action Language(None)

        imagebutton:
            style "accueil_bouton"
            idle Text(u"\uE021",style = "accueil_idle")
            hover Text(_("Bookmark"), style = "accueil_hover")
            action ShowMenu("load")

        imagebutton:
            style "accueil_bouton"
            xsize 200
            idle Text(u"\uE0A9",style = "accueil_idle", size = 80)
            hover Text(_("Read"), style = "accueil_hover" ,size = 50)
            action Start()

        imagebutton:
            style "accueil_bouton"
            idle Text(u"\uE041",style = "accueil_idle")
            hover Text(_("Options"), style = "accueil_hover")
            action ShowMenu("menu_general")

        imagebutton:
            style "accueil_bouton"
            idle Text(u"\uE0AB",style = "accueil_idle")
            hover Text(_("Quit"), style = "accueil_hover")
            action Quit(confirm=False)

        #textbutton _("Start Game") action Start()
        #textbutton _("Load Game") action ShowMenu("load")
        #textbutton _("Preferences") action ShowMenu("preferences")
        #textbutton _("Help") action Help()
        #textbutton _("Quit") action Quit(confirm=False)
        ##rajout d'un bouton qui permet de changer de langue, dans le menu principal
        #if _preferences.language == None:
        #    textbutton ("English") action Language("en")
        #else:
        #    textbutton (u"Français") action Language(None)

init -2 python:

    # Donne la même taille à tous les boutons du menu.
    style.mm_button.size_group = "mm"

init -2:
    # styles pour l'affichage des boutons de l'écran d'accueil
    style accueil_idle:
        font "gui/open-iconic.ttf"
        size 30
        #text_align 0.5
        color "#4D3B29" #style.button_text.selected_color
        outlines [(0,"#B99D83",2,2)]
        xalign 0.5
        yalign 0.5

    style accueil_hover is button_text:
        color "#4D3B29" #style.default.selected_color
        outlines [(0,"#B99D83",2,2)]
        text_align 0.5
        xalign 0.5
        yalign 0.5

    style accueil_bouton:
        xminimum 175
        ysize 100
        xmargin 25

##############################################################################
# Navigation
#
# Écran inclu dans d'autres écrans pour afficher le menu jeu,
# et le fond.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation:

    # Fond du menu jeu
    window:
        style "gm_root"

    # Boutons de navigation.
    frame:
        style_group "gm_nav"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Return") action Return()
        #textbutton _("Preferences") action ShowMenu("preferences")
        #textbutton _("Save Game") action ShowMenu("save")
        #textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Main Menu") action MainMenu()
        textbutton _("Quit") action Quit()

init -2 python:
    style.gm_nav_button.size_group = "gm_nav"


##############################################################################
# Sauvegarder, Charger
#
# Écrans permettant à l'utilisateur de sauvegarder ou charger un jeu
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Puisque la sauvegarde et le chargement sont deux actions proches
# nous utilisons un seul écran pour les deux. On utilise un l'écran
# file_picker depuis les écrans de sauvegarde et et de chargement.

screen file_picker:

    frame:
        style "file_picker_frame"

        has vbox

        # Les boutons en haut permettent à l'utilisateur
        # de sélectionner une page de fichiers.
        hbox:
            style_group "file_picker_nav"

            textbutton _("Previous"):
                action FilePagePrevious()

            textbutton _("Auto"):
                action FilePage("auto")

            textbutton _("Quick"):
                action FilePage("quick")

            for i in range(1, 9):
                textbutton str(i):
                    action FilePage(i)

            textbutton _("Next"):
                action FilePageNext()

        $ columns = 2
        $ rows = 5

        # Affiche une grille d'emplacements de sauvegarde
        grid columns rows:
            transpose True
            xfill True
            style_group "file_picker"

            # Montre dix emplacements, numérotés de 1 à 10.
            for i in range(1, columns * rows + 1):

                # Chaque emplacement est un bouton.
                button:
                    action FileAction(i)
                    xfill True

                    has hbox

                    # Ajoute un screenshot.
                    add FileScreenshot(i)

                    $ file_name = FileSlotName(i, columns * rows)
                    $ file_time = FileTime(i, empty=_("Empty Slot."))
                    $ save_name = FileSaveName(i)

                    text "[file_name]. [file_time!t]\n[save_name!t]"

                    key "save_delete" action FileDelete(i)


screen save:

    # Pour être sûr que tout autre menu est remplacé.
    tag menu

    use navigation
    use file_picker

screen load:

    # Pour être sûr que tout autre menu est remplacé.
    tag menu

    use navigation
    use file_picker

init -2 python:
    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_text = Style(style.large_button_text)



##############################################################################
# Préférences
#
# Écran permettant à l'utilisateur de changer les préférences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces

screen preferences:

    tag menu

    # Inclus la navigation.
    use navigation



    # Met les colonnes de navigation dans une grille de largeur 3.
    grid 3 1:
        style_group "prefs"
        xfill True

        # Colonne de gauche.
        vbox:
            # rajout d'un boîte pour changer de langue
            frame:
                style_group "pref"
                has vbox

                label _("Language")
                textbutton "Français" action Language(None)
                textbutton "English" action Language("en")

            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") action Preference("display", "window")
                textbutton _("Fullscreen") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                textbutton _("All") action Preference("transitions", "all")
                textbutton _("None") action Preference("transitions", "none")

#            frame:
#                style_group "pref"
#                has vbox

#                textbutton _("Joystick...") action Preference("joystick")

        # Colonne du milieu.
        vbox:
#            frame:
#                style_group "pref"
#                has vbox

#                label _("Skip")
#                textbutton _("Seen Messages") action Preference("skip", "seen")
#                textbutton _("All Messages") action Preference("skip", "all")

#            frame:
#                style_group "pref"
#                has vbox

#                textbutton _("Begin Skipping") action Skip()

#            frame:
#                style_group "pref"
#                has vbox

#                label _("After Choices")
#                textbutton _("Stop Skipping") action Preference("after choices", "stop")
#                textbutton _("Keep Skipping") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward")
                textbutton _("Auto-Forward") action Preference("auto-forward", "enable")
                textbutton _("No Auto-Forward") action Preference("auto-forward", "disable")

            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward Time")
                bar value Preference("auto-forward time")

                if config.has_voice:
                    textbutton _("Wait for Voice") action Preference("wait for voice", "toggle")

            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton _("Test"):
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            if config.has_voice:
                frame:
                    style_group "pref"
                    has vbox

                    label _("Voice Volume")
                    bar value Preference("voice volume")

                    textbutton _("Voice Sustain") action Preference("voice sustain", "toggle")
                    if config.sample_voice:
                        textbutton _("Test"):
                            action Play("voice", config.sample_voice)
                            style "soundtest_button"

init -2 python:
    style.pref_frame.xfill = True
    style.pref_frame.xmargin = 5
    style.pref_frame.top_margin = 5

    style.pref_vbox.xfill = True

    style.pref_button.size_group = "pref"
    style.pref_button.xalign = 1.0

    style.pref_slider.xmaximum = 192
    style.pref_slider.xalign = 1.0

    style.soundtest_button.xalign = 1.0


##############################################################################
# Menu Oui/Non
#
# Écran proposant à l'utilisateur une question oui ou non
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt

screen yesno_prompt:

    modal True

    window:
        style "gm_root"

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05

        has vbox:
            xalign .5
            yalign .5
            spacing 30

        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100

            textbutton _("Yes") action yes_action
            textbutton _("No") action no_action

    # Clic droit ou échap pour "non"
    key "game_menu" action no_action

init -2 python:
    style.yesno_button.size_group = "yesno"
    style.yesno_label_text.text_align = 0.5
    style.yesno_label_text.layout = "subtitle"


##############################################################################
# Menu rapide
#
# Écran inclus par défaut pour les dialogues, ajoutant un accès rapide à
# plusieurs fonctions utiles
screen quick_menu():

    # Ajoute un menu rapide au sein du jeu
    vbox:
        #style_group "quick"

        xalign 1.0
        yalign 1.0
        xoffset -4

        for i in range(len(quick_boutons)):
                imagebutton:
                    yminimum 18
                    xalign 1.0
                    idle Text(quick_boutons[i]["image"],style="quick_button_idle")#im.MatrixColor(quick_boutons[i]["icone"],im.matrix.invert() * im.matrix.tint(1.0,1.0,1.0) * im.matrix.opacity(0.53))
                    hover Text(quick_boutons[i]["texte"],style="quick_button_hover")
                    insensitive Text(quick_boutons[i]["image"],style="quick_button_insensitive")#im.MatrixColor(quick_boutons[i]["icone"], im.matrix.invert() * im.matrix.tint(0.27,0.27,0.27) * im.matrix.opacity(0.53))
                    if quick_boutons[i]["nom"] == "avance_auto":
                        selected_idle Text(u"\uE099",style="quick_button_selected")
                    else:
                        selected_idle Text(quick_boutons[i]["image"],style="quick_button_selected")#im.MatrixColor(quick_boutons[i]["icone"], im.matrix.invert() * im.matrix.tint(1.0,1.0,0.0) * im.matrix.opacity(1.0))
                    if quick_boutons[i]["nom"] == "avance_auto":
                        selected_hover Text(u"Auto Off",style="quick_button_hover")
                    action quick_boutons[i]["action"]
                null height 5

init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None

    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12

    style.quick_button_image.set_parent('quick_button')
    style.quick_button_image.font="gui/open-iconic.ttf"
    style.quick_button_image.size=14

    style.quick_button_idle = Style(style.quick_button_image)
    style.quick_button_idle.color = "#ddd8"
    style.quick_button_idle.outlines = [(1,"#0008",1,1)]

    style.quick_button_hover = Style(style.quick_button_text)
    style.quick_button_hover.color = "#ddd8"
    style.quick_button_hover.outlines = [(1,"#0008",1,1)]

    style.quick_button_selected = Style(style.quick_button_image)
    style.quick_button_selected.color = "#3338"
    style.quick_button_selected.outlines = [(1,"#fff8",1,1)]

    style.quick_button_insensitive = Style(style.quick_button_image)
    style.quick_button_insensitive.color = "#7778"
    #style.quick_button_insensitive.outlines = [(1,"#fff",1,1)]

##############################################################################
# Screens pour les crédits
#
#
# Screen général
screen credit(type,illu,description):
# type = l'écran est différent pour une image ou un fichier audio
# Illu = image qui sera affichée comme illustration (la phto, la couv de l'album, la représentation du bruitage)
# description = éléments pour la desciption (sous forme de tableau): auteur, nom de l'asset, licence, ...


    # À gauche : on a soit une simple image, soit image + boutons si c'est du son, donc un screen spécial (audio_illu)
    if type == "audio":
        use audio_illu(illu)
    else:
        add illu anchor (0.5,0.5) ypos 300 xpos 668/2

    # les items sont différents si on décrit une image ou du son (chacun a son propre screen)
    # on garde une solution par défaut où on reproduit simplement la chaine de caractère passée en argument
    if type == "audio":
        use audio_description(description)
    elif type == "image":
        use image_description(description)
    else:
        vbox:
            xpos 635 + 68
            ypos 100
            xsize 330
            text description style "st_credit"

style st_credit:
    color "#ccc"


# Affichage de la pochette et des boutons pour jouer musiques et sons (pour les crédits)
#
screen audio_illu(donnees):

    vbox:
        style_group "audioillu"
        xanchor 0.5
        ypos 100
        xpos 668/2
        add donnees['illu']
        null height 20
        textbutton _("Jouer") action Play("music",donnees['morceau'], loop=False)
        null height 20
        textbutton _("Stop") action Stop ("music")

# pour mettre tous les boutons à la même largeur
init -2 python:
    style.audioillu_button.size_group = "audioillu"


# Affichage de la description des musiques / sons
#
screen audio_description(infos):

    $ licence = affich_licence(infos['licence'],infos['version'])

    vbox:
        xpos 635 + 68
        ypos 100
        xsize 330

        # Affichage du titre de la description en fonction de la langue
        if _preferences.language == None:
            $ lang = "fr"
        else:
            $ lang = _preferences.language
        $ types = {"musique": {"fr":"Musique","en":"Music"},"son":{"fr":"Effet sonore","en":"Sound effect"}}

        text "{b}" + types[infos['type']][lang] + "{/b}" style "st_credit"
        null height 20
        $ par = _('par')
        text "[infos[titre]] [par!t] [infos[auteur]]" style "st_credit"
        null height 20
        if infos['type'] == "musique" and infos['album'] is not None:
            text _("Album : ") + infos ['album'] style "st_credit"
        null height 20
        $ credit_licence = _("sous licence\nCreative Commons")
        text  "[credit_licence!t]" style "st_credit"
        text licence style "st_credit"
        null height 20
        $ ecouter = _("}Écouter sur ")
        text "{a=[infos[lien]][ecouter!t] [infos[site]]{/a}" style "st_credit"


# Affichage de la description des images
#
screen image_description(infos):

    $ licence = affich_licence(infos['licence'],infos['version'])

    vbox:
        xpos 635 + 68
        ypos 100
        xsize 330

        text "{b}" + infos['titre'] + "{/b}" style "st_credit"
        null height 20
        $ par = _('par')
        text "[par!t] [infos[auteur]]" style "st_credit"
        if infos ['pseudo'] is not None:
            text "(" + infos ['pseudo'] + ")" style "st_credit"
        null height 20
        $ flickr = _("}original sur Flickr{/a}\n\nsous licence\nCreative Commons")
        text "{a=[infos[lien]][flickr!t]"  style "st_credit"
        text licence style "st_credit"
